==> breeze_website_builder_6.5.02.tar.gz: manage/plugins/lang/gallery/eo.php <==
<?php
////////////////////////////////////////////////////////////////////////
// Breeze Website Builder
// Copyright Silver Dolphin Solutions, LLC, Edward Lemmers, P.E.
// For licensing, see license.txt.
// Created: 3/1/2015	ELL

///////////////////////// Manage Gallery Parameters /////////////////////////
// Buttons:
define('MANAGE_GALLERY_HEADING', "Administri Lightbox Gallary Parametroj");
define('MANAGE_GALLERY_MANAGE_GALLERY_BTN', "administri Galerio");
// Console Text:
define('MANAGE_GALLERY_FULL_WIDTH', "Kompleta Grandeco Bildo Larĝeco");
define('MANAGE_GALLERY_FULL_HEIGHT', "Kompleta Grandeco Bildo Alteco");
define('MANAGE_GALLERY_THUMB_WIDTH', "Bildeto bilda Larĝeco");
define('MANAGE_GALLERY_THUMB_HEIGHT', "Bildeto bilda Alteco");
define('MANAGE_GALLERY_PRESERVE_THUMB_ASPECT', "Preserve Dikfingro Aspect Ratio");
define('MANAGE_GALLERY_SHOW_TITLES', "Montri Titoloj");
define('MANAGE_GALLERY_DISABLE_SORT', "malebligi Ordigi");
define('MANAGE_GALLERY_DELETE_IMAGE', "forigi Bildo");
define('MANAGE_GALLERY_SAVE_SORT_ORDER', "Konservu Ordigi Mendu");
define('MANAGE_GALLERY_PUBLISH_MSG', "Klaku &#39;Ĝisdatigo&#39; eldoni <br /> via alŝutita bildoj.");
// Popup Messages:
define('MANAGE_GALLERY_UPDATE_SUCCESS_MSG', "Ĉiuj bildoj estis regrandigo kaj agordo estas konservita.");
define('MANAGE_GALLERY_UPDATE_FAIL_ERR', "Okazis eraro regrandigi bildoj aŭ savi agordojn.");
define('MANAGE_GALLERY_UPLOAD_SUCCESS_MSG', "Via bildo (j) estis alŝutita.");
define('MANAGE_GALLERY_UPLOAD_FAIL_ERR', "Okazis eraro alŝuti vian bildon (j).");
define('MANAGE_GALLERY_UPLOAD_NOT_IMAGE_ERR', "La dosiero kiun vi provas alŝuti ne estas bildo.");
define('MANAGE_GALLERY_UPLOAD_TOO_BIG_ERR', "La dosiero kiun vi provas alŝuti estas tro granda.");
define('MANAGE_GALLERY_UPDATE_TITLE_SUCCESS_MSG', "La titolo estis konservita.");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_1_MSG', "Ĉu vi vere volas forigi bildon");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_2_MSG', "?");
define('MANAGE_GALLERY_DELETE_IMAGE_SUCCESS_MSG', "La bildo estis forigita.");
define('MANAGE_GALLERY_DELETE_IMAGE_FAIL_ERR', "Eraro forigante la bildo.");
define('MANAGE_GALLERY_SAVING_PARAMS_MSG', "Ŝparante parametroj kaj regrandigi bildoj, bonvolu atendi ...");
define('MANAGE_GALLERY_UPLOADING_IMAGES_MSG', "Uploading, bonvolu atendi ...");
define('MANAGE_GALLERY_NOT_SAVED_MSG', "La varo ordo ne estas konservitaj. Ĉu vi volas konservi la speco ordo?");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_SUCCESS_MSG', "La bildo speco ordo estas konservita.");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_FAIL_ERR', "Okazis eraro dum konservo de la bildo varo.");
?>

==> breeze_website_builder_6.6.18.tar.gz: manage/plugins/lang/gallery/eo.php <==
<?php
////////////////////////////////////////////////////////////////////////
// Breeze Website Builder
// Copyright Silver Dolphin Solutions, LLC, Edward Lemmers, P.E.
// For licensing, see license.txt.
// Created: 3/1/2015	ELL

///////////////////////// Manage Gallery Parameters /////////////////////////
// Buttons:
define('MANAGE_GALLERY_HEADING', "Administri Lightbox Gallary Parametroj");
define('MANAGE_GALLERY_MANAGE_GALLERY_BTN', "administri Galerio");
// Console Text:
define('MANAGE_GALLERY_FULL_WIDTH', "Kompleta Grandeco Bildo Larĝeco");
define('MANAGE_GALLERY_FULL_HEIGHT', "Kompleta Grandeco Bildo Alteco");
define('MANAGE_GALLERY_THUMB_WIDTH', "Bildeto bilda Larĝeco");
define('MANAGE_GALLERY_THUMB_HEIGHT', "Bildeto bilda Alteco");
define('MANAGE_GALLERY_PRESERVE_THUMB_ASPECT', "Preserve Dikfingro Aspect Ratio");
define('MANAGE_GALLERY_SHOW_TITLES', "Montri Titoloj");
define('MANAGE_GALLERY_DISABLE_SORT', "malebligi Ordigi");
define('MANAGE_GALLERY_DELETE_IMAGE', "forigi Bildo");
define('MANAGE_GALLERY_SAVE_SORT_ORDER', "Konservu Ordigi Mendu");
define('MANAGE_GALLERY_PUBLISH_MSG', "Klaku &#39;Ĝisdatigo&#39; eldoni <br /> via alŝutita bildoj.");
// Popup Messages:
define('MANAGE_GALLERY_UPDATE_SUCCESS_MSG', "Ĉiuj bildoj estis regrandigo kaj agordo estas konservita.");
define('MANAGE_GALLERY_UPDATE_FAIL_ERR', "Okazis eraro regrandigi bildoj aŭ savi agordojn.");
define('MANAGE_GALLERY_UPLOAD_SUCCESS_MSG', "Via bildo (j) estis alŝutita.");
define('MANAGE_GALLERY_UPLOAD_FAIL_ERR', "Okazis eraro alŝuti vian bildon (j).");
define('MANAGE_GALLERY_UPLOAD_NOT_IMAGE_ERR', "La dosiero kiun vi provas alŝuti ne estas bildo.");
define('MANAGE_GALLERY_UPLOAD_TOO_BIG_ERR', "La dosiero kiun vi provas alŝuti estas tro granda.");
define('MANAGE_GALLERY_UPDATE_TITLE_SUCCESS_MSG', "La titolo estis konservita.");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_1_MSG', "Ĉu vi vere volas forigi bildon");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_2_MSG', "?");
define('MANAGE_GALLERY_DELETE_IMAGE_SUCCESS_MSG', "La bildo estis forigita.");
define('MANAGE_GALLERY_DELETE_IMAGE_FAIL_ERR', "Eraro forigante la bildo.");
define('MANAGE_GALLERY_SAVING_PARAMS_MSG', "Ŝparante parametroj kaj regrandigi bildoj, bonvolu atendi ...");
define('MANAGE_GALLERY_UPLOADING_IMAGES_MSG', "Uploading, bonvolu atendi ...");
define('MANAGE_GALLERY_NOT_SAVED_MSG', "La varo ordo ne estas konservitaj. Ĉu vi volas konservi la speco ordo?");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_SUCCESS_MSG', "La bildo speco ordo estas konservita.");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_FAIL_ERR', "Okazis eraro dum konservo de la bildo varo.");
define('MANAGE_GALLERY_UPLOAD_BIGGER_THAN_ALLOWED_ERR', "The file you are trying to upload is bigger than the 'upload_max_filesize' or the 'post_max_size' PHP settings. Contact your system administrator to increase these limits.");
?>
